import {LayoutConfig} from "../types/LayoutConfig";

export class LayoutService {
  static configs: LayoutConfig[] = [];

  static async init(): Promise<void> {
    try {
      const activeConfigs = await fetch("/activeConfigs.json").then(content => content.json());
      const configFetches = (activeConfigs as string[])
        .map(configPath => fetch(configPath).then(content => content.json()));

      LayoutService.configs = await Promise.all(configFetches);
    } catch (e) {
      console.error("LayoutService could not init", e)
    }
  }

  static getActiveLayout(): LayoutConfig {
    const now = new Date();

    const activeConfigs = this.configs.filter(config => {
      if(config.schedule.always) {
        return true;
      }

      return config.schedule.times.reduce((accu, curr) => {
        if(accu) return true;
        return (curr.from <= now && curr.to >= now);
      }, false);
    });

    /* ToDo: This is not great, as it assumes there is always an active layout. If you don't configure this correctly,
             consider yourself warned now and don't blame me */
    return activeConfigs.reduce((accu, curr) => {
      if(!accu) {
        return curr;
      }

      if(accu.priority < curr.priority) {
        return curr;
      }

      return accu;
    })
  }
}
